#ifndef _UART_H_
#define _UART_H_

#include <avr/io.h>
#include <avr/pgmspace.h>

// Initialisiert den UART und aktiviert Receiver und Transmitter sowie den Receive-Interrupt.
// Die Ein- und Ausgebe-FIFO werden initialisiert. Das globale Interrupt-Enable-Flag
// (I-Bit in SREG) wird nicht verndert.
extern void uart_init(void);

// Speichert das Zeichen c in der Ausgabe-Warteschlange.
// Der return-Wert ist 1, falls das Zeichen in die FIFO eingetragen wurde, und 0,
// falls die Ausgabe-FIFO voll ist. Der UART DATA-Interupt wird aktiviert,
// der die Zeichen aus der Ausgabe-FIFO ber den UART verschickt.
extern int uart_putc (const uint8_t);
extern void uart_puts (const char *);
extern void uart_puts_wait (const char *);
extern void uart_puts_p (PGM_P);
extern void uart_puts_p_wait (PGM_P);

// Liefert das nchste empfangene Zeichen aus der Eingabe-FIFO bzw. wartet darauf,
// falls die FIFO leer ist.
extern uint8_t uart_getc_wait(void);

// Schaut nach, ob ein Zeichen empfangen wurde und liefert dieses gegebenenfalls als int zurck
// (Wertebereich ist 0...255). Wurde nichts empfangen, wird -1 geliefert.
extern int uart_getc_nowait(void);

// Lscht den Empfangspuffer
extern void uart_flush_rec(void);

// Wartet, bis die bertragung fertig ist
static inline void uart_flush_tran(void)
{
	while (LINENIR & (1 << LENTXOK));
}




#endif /* _UART_H_ */
